@@ -2,22 +2,6 @@ context("additional")
 
 
 
-test_that("neon_download_s3()", {
-  
-  
-  skip_on_cran()
-  skip_if_offline()
-  
-  x <- neon_download_s3(product = "DP1.10003.001",
-                     site = "YELL",
-                     start_date = "2018-01-01",
-                     end_date = "2019-01-01",
-                     dir = tempfile())
-  expect_is(x, "data.frame")
-  expect_gt(nrow(x), 0)
-  
-  
-})
 
 
 test_that("bigger neon_store() import", {
